import 'package:flutter/material.dart';

enum AnimationType { normal, fadeIn }

class AnimateRouteTransition {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;
  final Curve animateCurve;

  AnimateRouteTransition(
      {@required this.context,
      @required this.child,
      this.animation = AnimationType.fadeIn,
      this.duration = const Duration(milliseconds: 300),
      this.replacement = false,
      this.animateCurve = Curves.easeInOut}) {
    switch (this.animation) {
      case AnimationType.normal:
        this._normalTransition();
        break;
      case AnimationType.fadeIn:
        this._fadeInTransition();
        break;
    }
  }

  void _pushPage(Route route) => Navigator.push(context, route);

  void _pushReplacement(Route route) =>
      Navigator.pushReplacement(context, route);

  void _normalTransition() {
    final route = MaterialPageRoute(builder: (_) => this.child);
    (this.replacement) ? _pushReplacement(route) : _pushPage(route);
  }

  void _fadeInTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (_, __, ___) => this.child,
      transitionDuration: this.duration,
      transitionsBuilder: (_, animation, __, child) => FadeTransition(
          child: child,
          opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
              CurvedAnimation(parent: animation, curve: this.animateCurve))),
    );

    (this.replacement) ? _pushReplacement(route) : _pushPage(route);
  }
}
